@@ -1,21 +1,22 @@
 """Test for tmuxp configuration import, inlining, expanding and export."""
 
+from __future__ import annotations
+
 import pathlib
 import typing as t
 
 import pytest
 
+from tests.constants import EXAMPLE_PATH
 from tmuxp import exc
 from tmuxp._internal.config_reader import ConfigReader
 from tmuxp.workspace import loader, validation
 
-from ..constants import EXAMPLE_PATH
-
 if t.TYPE_CHECKING:
-    from ..fixtures.structures import WorkspaceTestData
+    from tests.fixtures.structures import WorkspaceTestData
 
 
-def load_workspace(path: t.Union[str, pathlib.Path]) -> t.Dict[str, t.Any]:
+def load_workspace(path: str | pathlib.Path) -> dict[str, t.Any]:
     """Load tmuxp workspace configuration from file."""
     return ConfigReader._from_file(
         pathlib.Path(path) if isinstance(path, str) else path,
@@ -24,7 +25,7 @@ def load_workspace(path: t.Union[str, pathlib.Path]) -> t.Dict[str, t.Any]:
 
 def test_export_json(
     tmp_path: pathlib.Path,
-    config_fixture: "WorkspaceTestData",
+    config_fixture: WorkspaceTestData,
 ) -> None:
     """Test exporting configuration dictionary to JSON."""
     json_workspace_file = tmp_path / "config.json"
@@ -39,13 +40,13 @@ def test_export_json(
     assert config_fixture.sample_workspace.sample_workspace_dict == new_workspace_data
 
 
-def test_workspace_expand1(config_fixture: "WorkspaceTestData") -> None:
+def test_workspace_expand1(config_fixture: WorkspaceTestData) -> None:
     """Expand shell commands from string to list."""
     test_workspace = loader.expand(config_fixture.expand1.before_workspace)
     assert test_workspace == config_fixture.expand1.after_workspace()
 
 
-def test_workspace_expand2(config_fixture: "WorkspaceTestData") -> None:
+def test_workspace_expand2(config_fixture: WorkspaceTestData) -> None:
     """Expand shell commands from string to list."""
     unexpanded_dict = ConfigReader._load(
         fmt="yaml",
@@ -128,7 +129,7 @@ def test_inheritance_workspace() -> None:
     assert workspace == inheritance_workspace_after
 
 
-def test_shell_command_before(config_fixture: "WorkspaceTestData") -> None:
+def test_shell_command_before(config_fixture: WorkspaceTestData) -> None:
     """Config inheritance for the nested 'start_command'."""
     test_workspace = config_fixture.shell_command_before.config_unexpanded
     test_workspace = loader.expand(test_workspace)
@@ -139,7 +140,7 @@ def test_shell_command_before(config_fixture: "WorkspaceTestData") -> None:
     assert test_workspace == config_fixture.shell_command_before.config_after()
 
 
-def test_in_session_scope(config_fixture: "WorkspaceTestData") -> None:
+def test_in_session_scope(config_fixture: WorkspaceTestData) -> None:
     """Verify shell_command before_session is in session scope."""
     sconfig = ConfigReader._load(
         fmt="yaml",
@@ -155,7 +156,7 @@ def test_in_session_scope(config_fixture: "WorkspaceTestData") -> None:
     )
 
 
-def test_trickle_relative_start_directory(config_fixture: "WorkspaceTestData") -> None:
+def test_trickle_relative_start_directory(config_fixture: WorkspaceTestData) -> None:
     """Verify tmuxp config proliferates relative start directory to descendants."""
     test_workspace = loader.trickle(config_fixture.trickle.before)
     assert test_workspace == config_fixture.trickle.expected
@@ -180,7 +181,7 @@ def test_trickle_window_with_no_pane_workspace() -> None:
     }
 
 
-def test_expands_blank_panes(config_fixture: "WorkspaceTestData") -> None:
+def test_expands_blank_panes(config_fixture: WorkspaceTestData) -> None:
     """Expand blank config into full form.
 
     Handle ``NoneType`` and 'blank'::
@@ -294,22 +295,21 @@ def test_replaces_env_variables(monkeypatch: pytest.MonkeyPatch) -> None:
       panes:
       - shell_command:
       - htop
-    """.format(TEST_VAR="${%s}" % env_key)
+    """.format(TEST_VAR=f"${{{env_key}}}")
 
     sconfig = ConfigReader._load(fmt="yaml", content=yaml_workspace)
 
     monkeypatch.setenv(str(env_key), str(env_val))
     sconfig = loader.expand(sconfig)
-    assert "%s/test" % env_val == sconfig["start_directory"]
+    assert f"{env_val}/test" == sconfig["start_directory"]
     assert (
-        "%s/test2" % env_val
-        in sconfig["shell_command_before"]["shell_command"][0]["cmd"]
+        f"{env_val}/test2" in sconfig["shell_command_before"]["shell_command"][0]["cmd"]
     )
-    assert "%s/test3" % env_val == sconfig["before_script"]
-    assert "hi - %s" % env_val == sconfig["session_name"]
-    assert "%s/moo" % env_val == sconfig["global_options"]["default-shell"]
-    assert "%s/lol" % env_val == sconfig["options"]["default-command"]
-    assert "logging @ %s" % env_val == sconfig["windows"][1]["window_name"]
+    assert f"{env_val}/test3" == sconfig["before_script"]
+    assert f"hi - {env_val}" == sconfig["session_name"]
+    assert f"{env_val}/moo" == sconfig["global_options"]["default-shell"]
+    assert f"{env_val}/lol" == sconfig["options"]["default-command"]
+    assert f"logging @ {env_val}" == sconfig["windows"][1]["window_name"]
 
 
 def test_validate_plugins() -> None:
